pub enum Ect {
Slow2g,
Type2g,
Type3g,
Type4g,
}Expand description
Sec-CH-ECT (Effective Connection Type) client hint.
Describes the measured network performance as one of an enumerated set of
connection profiles, each covering a range of Rtt and Downlink
values. See the
Network Information API.
Corresponds to ClientHint::Ect; encoded as Sec-CH-ECT.
Example
use rama_http_headers::Ect;
assert_eq!(Ect::Type4g.as_str(), "4g");Variants
Implementations
Sourceimpl Ect
impl Ect
Sourcepub const HINT: ClientHint = ClientHint::Ect
pub const HINT: ClientHint = ClientHint::Ect
The ClientHint this typed value parser corresponds to.