pub enum ContentEncodingDirective {
Gzip,
Compress,
Deflate,
Brotli,
ZStandard,
DCBrotli,
DCZStandard,
Unknown(Box<str>),
}Expand description
Directive for the ContentEncoding header.
Variants
Gzip
A format using the Lempel-Ziv coding (LZ77), with a 32-bit CRC. This is the original format of the UNIX gzip program.
The HTTP/1.1 standard also recommends that the servers supporting this content-encoding should recognize x-gzip as an alias, for compatibility purposes.
Compress
A format using the Lempel-Ziv-Welch (LZW) algorithm. The value name was taken from the UNIX compress program, which implemented this algorithm. Like the compress program, which has disappeared from most UNIX distributions, this content-encoding is not used by many browsers today, partly because of a patent issue (it expired in 2003).
Deflate
Using the zlib structure (defined in RFC 1950) with the deflate compression algorithm (defined in RFC 1951).
Brotli
ZStandard
DCBrotli
A format that uses the Dictionary-Compressed Brotli algorithm. See Compression Dictionary Transport.
Experimental directive still in Draft!
DCZStandard
A format that uses the Dictionary-Compressed Zstandard algorithm. See Compression Dictionary Transport.
Experimental directive still in Draft!
Unknown(Box<str>)
Implementations
Sourceimpl ContentEncodingDirective
impl ContentEncodingDirective
pub fn as_str(&self) -> &str
pub fn as_static_str(&self) -> Cow<'static, str>
pub fn as_smol_str(&self) -> __SmolStr
Sourceimpl ContentEncodingDirective
impl ContentEncodingDirective
Sourcepub fn strict_parse(s: &str) -> Option<Self>
pub fn strict_parse(s: &str) -> Option<Self>
Same as FromStr or From<&str> but returning
None for unknown values