pub enum TransferEncodingDirective {
Compress,
Deflate,
Gzip,
Chunked,
Unknown(Box<str>),
}Expand description
Directive for the TransferEncoding header.
Variants
Compress
A format using the Lempel-Ziv-Welch (LZW) algorithm.
The value name was taken from the UNIX compress program, which implemented this algorithm. Like the compress program, which has disappeared from most UNIX distributions, this content-encoding is used by almost no browsers today, partly because of a patent issue (which expired in 2003).
Deflate
Using the zlib structure (defined in RFC 1950) with the deflate compression algorithm (defined in RFC 1951).
Gzip
A format using the Lempel-Ziv coding (LZ77), with a 32-bit CRC. This is the original format of the UNIX gzip program.
The HTTP/1.1 standard also recommends that the servers supporting this content-encoding should recognize x-gzip as an alias, for compatibility purposes.
Chunked
Data is sent in a series of chunks.
Content can be sent in streams of unknown size to be transferred as a sequence of
length-delimited buffers, so the sender can keep a connection open,
and let the recipient know when it has received the entire message.
The Content-Length header must be omitted, and at the beginning of each chunk,
a string of hex digits indicate the size of the chunk-data in octets,
followed by \r\n and then the chunk itself, followed by another \r\n.
The terminating chunk is a zero-length chunk.
Unknown(Box<str>)
Implementations
Sourceimpl TransferEncodingDirective
impl TransferEncodingDirective
pub fn as_str(&self) -> &str
pub fn as_static_str(&self) -> Cow<'static, str>
pub fn as_smol_str(&self) -> __SmolStr
Sourceimpl TransferEncodingDirective
impl TransferEncodingDirective
Sourcepub fn strict_parse(s: &str) -> Option<Self>
pub fn strict_parse(s: &str) -> Option<Self>
Same as FromStr or From<&str> but returning
None for unknown values