pub struct XForwardedHost(/* private fields */);Expand description
The X-Forwarded-Host (XFH) header is a de-facto standard header for identifying the original host requested by the client in the Host HTTP request header.
It is recommended to use the Forwarded header instead if you can.
More info can be found at https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Forwarded-Host.
Syntax
X-Forwarded-Host: <host>Example values
id42.example-cdn.comid42.example-cdn.com:443203.0.113.195203.0.113.195:802001:db8:85a3:8d3:1319:8a2e:370:7348[2001:db8:85a3:8d3:1319:8a2e:370:7348]:8080
Implementations
Sourceimpl XForwardedHost
impl XForwardedHost
Sourcepub fn host(&self) -> &Host
pub fn host(&self) -> &Host
Get a reference to the Host of this XForwardedHost.
Sourcepub fn port(&self) -> Option<u16>
pub fn port(&self) -> Option<u16>
Get a copy of the port of this XForwardedHost if it is set.
Empty (: with no digits) maps to None along with truly absent.
Sourcepub fn inner(&self) -> &ForwardedAuthority
pub fn inner(&self) -> &ForwardedAuthority
Return a reference to the inner data of this header.
Sourcepub fn into_inner(self) -> ForwardedAuthority
pub fn into_inner(self) -> ForwardedAuthority
Consume this header into its inner data.