Allow

Struct Allow 

pub struct Allow(pub NonEmptySmallVec<7, Method>);
Allow header, defined in RFC7231

The Allow header field lists the set of methods advertised as supported by the target resource. The purpose of this field is strictly to inform the recipient of valid request methods associated with the resource.

ABNF

Allow = #method

Example values

  • GET, HEAD, PUT
  • OPTIONS, GET, PUT, POST, DELETE, HEAD, TRACE, CONNECT, PATCH, fOObAr
  • ``

Examples

use rama_utils::collections::non_empty_smallvec;
use rama_http_types::Method;
use rama_http_headers::Allow;

let allow_methods = Allow(
    non_empty_smallvec![Method::GET, Method::PUT],
);

Tuple Fields

0: NonEmptySmallVec<7, Method>

Implementations

Source

impl Allow

pub fn new(value: Method) -> Self