pub struct Connection(/* private fields */);Expand description
Connection header, defined in
RFC7230
The Connection header field allows the sender to indicate desired
control options for the current connection. In order to avoid
confusing downstream recipients, a proxy or gateway MUST remove or
replace any received connection options before forwarding the
message.
ABNF
Connection = 1#connection-option
connection-option = token
# Example values
* `close`
* `keep-alive`
* `upgrade`
* `keep-alive, upgrade`Examples
use rama_http_headers::Connection;
let keep_alive = Connection::keep_alive();Implementations
Sourceimpl Connection
impl Connection
pub fn iter_headers(&self) -> impl Iterator<Item = &HeaderName>
Sourceimpl Connection
impl Connection
Sourcepub fn open(headers: NonEmptyVec<HeaderName>) -> Self
pub fn open(headers: NonEmptyVec<HeaderName>) -> Self
A constructor to easily create a Connection header,
for the given header names.
Sourcepub fn is_close(&self) -> bool
pub fn is_close(&self) -> bool
Returns true if this Connection header contains close.
Sourcepub fn keep_alive() -> Self
pub fn keep_alive() -> Self
A constructor to easily create a Connection: keep-alive header.
Sourcepub fn contains_header(&self, name: impl PartialEq<HeaderName>) -> bool
pub fn contains_header(&self, name: impl PartialEq<HeaderName>) -> bool
Returns true if this Connection header contains the given header.
Example
use rama_http_types::header::UPGRADE;
use rama_http_headers::Connection;
let conn = Connection::keep_alive();
assert!(!conn.contains_header(UPGRADE));
assert!(conn.contains_header("keep-alive"));
assert!(conn.contains_header("Keep-Alive"));Sourcepub fn contains_upgrade(&self) -> bool
pub fn contains_upgrade(&self) -> bool
Returns true if this Connection header contains Upgrade.
Example
use rama_http_headers::Connection;
assert!(!Connection::keep_alive().contains_upgrade());
assert!(Connection::upgrade().contains_upgrade());Sourcepub fn contains_keep_alive(&self) -> bool
pub fn contains_keep_alive(&self) -> bool
Returns true if this Connection header contains Keep-Alive.
Example
use rama_http_headers::Connection;
assert!(Connection::keep_alive().contains_keep_alive());
assert!(!Connection::upgrade().contains_keep_alive());Trait Implementations
Sourceimpl Clone for Connection
impl Clone for Connection
Sourcefn clone(&self) -> Connection
fn clone(&self) -> Connection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Connection
impl Debug for Connection
Sourceimpl HeaderDecode for Connection
impl HeaderDecode for Connection
Sourcefn decode<'i, I>(values: &mut I) -> Result<Self, Error>where
I: Iterator<Item = &'i HeaderValue>,
fn decode<'i, I>(values: &mut I) -> Result<Self, Error>where
I: Iterator<Item = &'i HeaderValue>,
Decode this type from an iterator of
HeaderValues.Sourceimpl HeaderEncode for Connection
impl HeaderEncode for Connection
Sourcefn encode<E: Extend<HeaderValue>>(&self, values: &mut E)
fn encode<E: Extend<HeaderValue>>(&self, values: &mut E)
Encode this type to a
HeaderValue, and add it to a container
which has HeaderValue type as each element. Read moreSourcefn encode_to_value(&self) -> Option<HeaderValue>
fn encode_to_value(&self) -> Option<HeaderValue>
Encode this header to
HeaderValue. Read moreSourceimpl TypedHeader for Connection
impl TypedHeader for Connection
Sourcefn name() -> &'static HeaderName
fn name() -> &'static HeaderName
The name of this header.