pub struct ContentEncoding(pub NonEmptyVec<ContentEncodingDirective>);Expand description
Content-Encoding header, defined in
RFC7231
The Content-Encoding header field indicates what content codings
have been applied to the representation, beyond those inherent in the
media type, and thus what decoding mechanisms have to be applied in
order to obtain data in the media type referenced by the Content-Type
header field. Content-Encoding is primarily used to allow a
representation’s data to be compressed without losing the identity of
its underlying media type.
ABNF
Content-Encoding = 1#content-codingExample values
gzipbrzstddeflate, gzip
Examples
use rama_http_headers::ContentEncoding;
let content_enc = ContentEncoding::gzip();Tuple Fields
0: NonEmptyVec<ContentEncodingDirective>Implementations
Sourceimpl ContentEncoding
impl ContentEncoding
pub fn new(value: ContentEncodingDirective) -> Self
Sourceimpl ContentEncoding
impl ContentEncoding
Sourcepub fn new_multi(directives: NonEmptyVec<ContentEncodingDirective>) -> Self
pub fn new_multi(directives: NonEmptyVec<ContentEncodingDirective>) -> Self
Create a new ContentEncoding header with multiple directives.
Meaning the content is encoded with all given directives and in order.
Sourcepub fn contains_directive(&self, coding: impl CmpCoding) -> bool
pub fn contains_directive(&self, coding: impl CmpCoding) -> bool
Check if this header contains a given “coding”.
This can be used with these argument types:
&str
Example
use rama_http_headers::ContentEncoding;
let content_enc = ContentEncoding::gzip();
assert!(content_enc.contains_directive("gzip"));
assert!(!content_enc.contains_directive("br"));Trait Implementations
Sourceimpl Clone for ContentEncoding
impl Clone for ContentEncoding
Sourcefn clone(&self) -> ContentEncoding
fn clone(&self) -> ContentEncoding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContentEncoding
impl Debug for ContentEncoding
Sourceimpl HeaderDecode for ContentEncoding
impl HeaderDecode for ContentEncoding
Sourcefn decode<'i, I>(values: &mut I) -> Result<Self, Error>where
I: Iterator<Item = &'i HeaderValue>,
fn decode<'i, I>(values: &mut I) -> Result<Self, Error>where
I: Iterator<Item = &'i HeaderValue>,
Decode this type from an iterator of
HeaderValues.Sourceimpl HeaderEncode for ContentEncoding
impl HeaderEncode for ContentEncoding
Sourcefn encode<E: Extend<HeaderValue>>(&self, values: &mut E)
fn encode<E: Extend<HeaderValue>>(&self, values: &mut E)
Encode this type to a
HeaderValue, and add it to a container
which has HeaderValue type as each element. Read moreSourcefn encode_to_value(&self) -> Option<HeaderValue>
fn encode_to_value(&self) -> Option<HeaderValue>
Encode this header to
HeaderValue. Read moreSourceimpl TypedHeader for ContentEncoding
impl TypedHeader for ContentEncoding
Sourcefn name() -> &'static HeaderName
fn name() -> &'static HeaderName
The name of this header.