pub struct Location(/* private fields */);Expand description
Location header, defined in
RFC7231
The Location header field is used in some responses to refer to a
specific resource in relation to the response. The type of
relationship is defined by the combination of request method and
status code semantics.
ABNF
Location = URI-referenceExample values
/People.html#timhttp://www.example.net/index.html
Examples
Implementations