pub struct Server(/* private fields */);Expand description
Server header, defined in RFC7231
The Server header field contains information about the software
used by the origin server to handle the request, which is often used
by clients to help identify the scope of reported interoperability
problems, to work around or tailor requests to avoid particular
server limitations, and for analytics regarding server or operating
system use. An origin server MAY generate a Server field in its
responses.
ABNF
Server = product *( RWS ( product / comment ) )Example values
CERN/3.0 libwww/2.17
Example
use rama_http_headers::Server;
let server = Server::from_static("hyper/0.12.2");Implementations