pub struct Te(pub NonEmptySmallVec<2, QualityValue<TeDirective>>);Expand description
TE header, defined in
RFC7230
As RFC7230 states, “The “TE” header field in a request indicates what transfer codings, besides chunked, the client is willing to accept in response, and whether or not the client is willing to accept trailer fields in a chunked transfer coding.“
For HTTP/1.1 compliant clients chunked transfer codings are assumed to be acceptable and
so should never appear in this header.
ABNF
TE = "TE" ":" #( t-codings )
t-codings = "trailers" | ( transfer-extension [ accept-params ] )Example values
trailerstrailers, deflate;q=0.5
Tuple Fields
0: NonEmptySmallVec<2, QualityValue<TeDirective>>Implementations
Sourceimpl Te
impl Te
pub fn new(value: QualityValue<TeDirective>) -> Self