TransferEncoding

Struct TransferEncoding 

pub struct TransferEncoding(pub NonEmptySmallVec<2, TransferEncodingDirective>);
Transfer-Encoding header, defined in RFC7230

The Transfer-Encoding header field lists the transfer coding names corresponding to the sequence of transfer codings that have been (or will be) applied to the payload body in order to form the message body.

Note that setting this header will remove any previously set Content-Length header, in accordance with RFC7230:

A sender MUST NOT send a Content-Length header field in any message that contains a Transfer-Encoding header field.

ABNF

Transfer-Encoding = 1#transfer-coding

Example values

  • chunked
  • gzip, chunked

Example

use rama_http_headers::TransferEncoding;

let transfer = TransferEncoding::chunked();

Tuple Fields

0: NonEmptySmallVec<2, TransferEncodingDirective>

Implementations

Source

impl TransferEncoding

pub fn new(value: TransferEncodingDirective) -> Self

Source

impl TransferEncoding

pub fn chunked() -> Self

Constructor for the most common Transfer-Encoding, chunked.

pub fn is_chunked(&self) -> bool

Returns whether this ends with the chunked encoding.