pub struct UserAgent(/* private fields */);Expand description
User-Agent header, defined in
RFC7231
The User-Agent header field contains information about the user
agent originating the request, which is often used by servers to help
identify the scope of reported interoperability problems, to work
around or tailor responses to avoid particular user agent
limitations, and for analytics regarding browser or operating system
use. A user agent SHOULD send a User-Agent field in each request
unless specifically configured not to do so.
ABNF
User-Agent = product *( RWS ( product / comment ) )
product = token ["/" product-version]
product-version = tokenExample values
CERN-LineMode/2.15 libwww/2.17b3Bunnies
Notes
- The parser does not split the value
Example
use rama_http_headers::UserAgent;
let ua = UserAgent::from_static("hyper/0.12.2");Implementations