pub struct XForwardedProto(/* private fields */);Expand description
The X-Forwarded-Proto (XFP) header is a de-facto standard header for identifying the protocol (HTTP or HTTPS) that a client used to connect to your proxy or load balancer.
Your server access logs contain the protocol used between the server and the load balancer, but not the protocol used between the client and the load balancer. To determine the protocol used between the client and the load balancer, the X-Forwarded-Proto request header can be used.
It is recommended to use the Forwarded header instead if you can.
More info can be found at https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Forwarded-Proto.
Syntax
X-Forwarded-Proto: <protocol>Example values
httpshttp
Implementations
Sourceimpl XForwardedProto
impl XForwardedProto
Sourcepub fn protocol(&self) -> &ForwardedProtocol
pub fn protocol(&self) -> &ForwardedProtocol
Get a reference to the ForwardedProtocol of this XForwardedProto.
Sourcepub fn into_protocol(self) -> ForwardedProtocol
pub fn into_protocol(self) -> ForwardedProtocol
Consume this Header into the inner data (ForwardedProtocol).