#[non_exhaustive]pub struct Dnt;Expand description
The HTTP DNT (Do Not Track) request header indicates the user’s tracking preference.
It lets users indicate whether they would prefer privacy rather than personalized content.
Dnt in the wild is deprecated in favor of Global Privacy Control,
which is communicated to servers using the Sec-GPC header,
and accessible to clients from navigator.globalPrivacyControl.
Implementations