pub struct Authorization<C>(pub C);Expand description
Authorization header, defined in RFC7235
The Authorization header field allows a user agent to authenticate
itself with an origin server – usually, but not necessarily, after
receiving a 401 (Unauthorized) response. Its value consists of
credentials containing the authentication information of the user
agent for the realm of the resource being requested.
ABNF
Authorization = credentialsExample values
Basic QWxhZGRpbjpvcGVuIHNlc2FtZQ==Bearer fpKL54jvWmEGVoRdCNjG
Examples
use rama_http_headers::Authorization;
use rama_net::user::credentials::{basic, bearer};
let basic = Authorization::new(basic!("Aladdin", "open sesame"));
let bearer = Authorization::new(bearer!("some-opaque-token"));Tuple Fields
0: CImplementations
Sourceimpl<C> Authorization<C>
impl<C> Authorization<C>
pub fn credentials(&self) -> &C
pub fn into_inner(self) -> C